==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/sites/lang/sites_my.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=my
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => 'ပူးတွဲချိတ်ဆက်မှု အ​ဆင်မ​​ပြေပါ၊ ချိတ်ဆက်မှုကို မဖတ်နိုင်တာ (သို့) ခွင့်ပြုချက် ပေးမထားခြင်းကြောင့် ဖြစ်နိုင်ပါသည်',
	'avis_echec_syndication_02' => 'ပူးတွဲချိတ်ဆက်မှု အ​ဆင်မ​​ပြေပါ၊ ဤဝက်ဘ်ဆိုက် အတွင်းဘက်နှင့် မချိတ်ဆက်နိုင်ပါ ',
	'avis_site_introuvable' => 'ဝက်ဘ်ဆိုက်ကို မတွေ့ပါ',
	'avis_site_syndique_probleme' => 'သတိပေးချက်၊ ဤဆိုက်၏ ပူးတွဲချိတ်ဆက်မှုတွင် ပြသနာရှိသည်၊ စက်တွင်နောက်ဆက်တွဲ ပြသနာခေတ္တရှိမည်၊ ဆိုက်၏ ပူးတွဲချိတ်ဆက်မှု လိပ်စာကို မှတ်ထားပါ (<b>@url_syndic@</b>) နောက်မှပြန်ကြိုးစားကြည့်ပါ', # MODIF
	'avis_sites_probleme_syndication' => 'ဤဆိုက်များတွင် ပူးတွဲချိတ်ဆက်မှု ပြသနာရှိနေသည်',
	'avis_sites_syndiques_probleme' => 'ဤ​ပူးတွဲချိတ်ဆက်ထား​သည့် ဆိုက်များတွင် ပြသနာရှိသည်',

	// B
	'bouton_radio_modere_posteriori' => 'နောက်မှ ထိန်းသိမ်းခြင်း', # MODIF
	'bouton_radio_modere_priori' => 'ကြိုတင် ထိန်းသိမ်းထားခြင်း', # MODIF
	'bouton_radio_non_syndication' => 'ပူးတွဲချတ်ဆက်မှုမလို',
	'bouton_radio_syndication' => '​ပူးတွဲချတ်ဆက်မှု',

	// E
	'entree_adresse_fichier_syndication' => 'ပူးတွဲချိတ်ဆက်မှုများ၏ လိပ်စာ',
	'entree_adresse_site' => '<b>ဝက်ဘ်ဆိုက်လိပ်စာ</b> [လိုအပ်ပါသည်]',
	'entree_description_site' => 'ဝက်ဘ်ဆိုက်ဖော်ပြချက်',

	// F
	'form_prop_nom_site' => 'ဆိုက်နာမည်',

	// I
	'icone_modifier_site' => 'ဤဝက်ဘ်ဆိုက်ကို ပြန်လည်မွမ်းမံပါ',
	'icone_referencer_nouveau_site' => 'ဝက်ဘ်ဆိုက် အသစ်တခုကို ကိုးကားပါ',
	'icone_voir_sites_references' => 'ကိုးကားဝက်ဘ်ဆိုက်များကို ပြပါ',
	'info_a_valider' => '[ထပ်မံအတည်ပြုရန်]',
	'info_bloquer' => 'အကွက်',
	'info_bloquer_lien' => 'ဤဆက်သွယ်မှုကို ပိတ်ပင်ရန်',
	'info_derniere_syndication' => 'ဝက်ဆိုက်၏ နောက်ပူးတွဲချိတ်ဆက်မှုသည် () သို့သွားသည်',
	'info_liens_syndiques_1' => 'အကျိုးတူဆက်နွယ်မှုများ',
	'info_liens_syndiques_2' => 'စံနှုန်းကိုက်ညီမှုစစ်ဆေးချက်ပယ်ဖျက်သည်',
	'info_nom_site_2' => '<b>ဝက်ဘ်ဆိုက်အမည်</b> [လိုအပ်ပါသည်]',
	'info_panne_site_syndique' => 'ပူးတွဲချိတ်ဆက်မှု ပျက်နေသည်',
	'info_probleme_grave' => 'အမှားအယွင်း',
	'info_question_proposer_site' => 'မည်သူက ကိုးကားဝက်ဘ်ဆိုက်များကို ထင်မြင်ချက်ပေးနိုင်သနည်း',
	'info_retablir_lien' => 'ဒီအချိတ်အဆက်ကို ပြန်လည်ထည့်သွင်းရန်',
	'info_site_attente' => 'ဝက်ဘ်ဆိုက် အတည်ပြုချက်ရရန် ဆိုင်းငံ့ခြင်းခံရသည်',
	'info_site_propose' => 'ဝက်ဘ်ဆိုက်ကို တင်သွင်းသည့်နေရာ',
	'info_site_reference' => 'အွန်လိုင်း အညွှန်းဆိုက်များ',
	'info_site_refuse' => 'ဝက်ဘ်ဆိုက်ငြင်းပယ်ခြင်းခံရသည်',
	'info_site_syndique' => 'ဤဝက်ဘ်ဆိုက်သည် ပူးတွဲချိတ်ဆက်ထားသော ဝက်ဘ်ဆိုက်ဖြစ်သည်', # MODIF
	'info_site_valider' => 'အတည်တကျဖြစ်မည့် ဝက်ဘ်ဆိုက်များ',
	'info_sites_referencer' => 'ဆိုက်ညွှန်းခြင်း',
	'info_sites_refuses' => 'ပယ်ဖျက်သည့် ဝက်ဘ်ဆိုက်များ',
	'info_statut_site_1' => 'ဤဝက်ဘ်ဆိုက်သည်',
	'info_statut_site_2' => 'ထုတ်ဝေသည်',
	'info_statut_site_3' => 'တင်ပြထားသည်',
	'info_statut_site_4' => 'အမှိုက်ပုံးထဲတွင်', # MODIF
	'info_syndication' => 'ပူးတွဲချိတ်ဆက်မှု',
	'info_syndication_articles' => 'ဆောင်းပါးများ',
	'item_bloquer_liens_syndiques' => 'ပူးတွဲချိတ်ဆက်မှုများကို အတည်တကျရှိခြင်းမှ ပိတ်ပင်လိုက်ပါ',
	'item_gerer_annuaire_site_web' => 'ဝက်ဘ်ဆိုက်အညွှန်းကို စီမံခန့်ခွဲပါ',
	'item_non_bloquer_liens_syndiques' => 'ပူးတွဲချိတ်ဆက်မှု စတင်နေခြင်းကို ပိတ်ပင်ခြင်း မလုပ်ပါနှင့်',
	'item_non_gerer_annuaire_site_web' => 'ဝက်ဘ်ဆိုက်လမ်းညွှန်ကို အသုံးမပြုနိုင်ပါ',
	'item_non_utiliser_syndication' => 'အလိုအလျေက်ပူးတွဲချိတ်ဆက်မူကို မသုံးပါနှင့်',
	'item_utiliser_syndication' => 'အလိုအလျေက် ပူးတွဲချိတ်ဆက်မှုကို အသုံးပြုပါ',

	// L
	'lien_mise_a_jour_syndication' => 'အခုပြန်လည်မွမ်းမံပါ',
	'lien_nouvelle_recuperation' => 'ဒေတာကို ကာကွယ်မှု ပြန်လည်ပြုလုပ်ရန်ကြိုးစားပါ',

	// S
	'syndic_choix_moderation' => 'ဤဝက်ဘ်ဆိုက်မှ နောက်တစ်ခုသို့ ဆက်နွယ်မှုများတွင် ဘာလုပ်ရမည်လဲ',
	'syndic_choix_oublier' => 'ပူးတွဲချိတ်ဆက်ဖိုင်တွင် အချိန်ကြာမြင့်စွာမရှိတော့သည့် ချိတ်ဆက်မှုကို ဘယ်လိုလုပ်သင့်သလဲ',
	'syndic_choix_resume' => 'အချို့ဝက်ဘ်ဆိုက်များက ဆောင်းပါး၏စာသားအားလုံးကို ကြည့်ခွင့်ပေးသည်။ ပူးတွဲချိတ်ဆက်ရန် ဆန္ဒရှိပါသလား',
	'syndic_lien_obsolete' => 'ဆက်နွယ်မှုအပြည့်စုံ',
	'syndic_option_miroir' => 'အဲဒါတွေကို အလိုအလျောက် ပိတ်ပင်လိုက်ပါ',
	'syndic_option_oubli' => 'အဲဒါတွေကို ဖျက်ပစ်ပါ (ပြီးနောက် @mois@ လများ)',
	'syndic_option_resume_non' => 'ဆောင်းပါးများ၏ အညွှန်းအပြည့်စုံ (HTML ပုံစံ)',
	'syndic_option_resume_oui' => 'နမူနာသာ (စာသားပုံစံ)',
	'syndic_options' => 'ပူးတွဲချိတ်ဆက်မှုဆိုင်ရာ ရွေးချယ်ခွင့်များ',

	// T
	'texte_liens_sites_syndiques' => 'ပြန့်ပွားသော ပူးတွဲချိတ်ဆက်မှု ဆိုက်များကို ပိတ်ပင်ခြင်း ခံရမည်။ ချိတ်ဆက်မှု အချက်အလက်များကို ပူးတွဲချိတ်ဆက်ခြင်း အောင်မြင်စွာ ဖန်တီးပြီးချင်း အောက်တွင်ဖော်ပြပါသည်။ လိပ်စာတခုခြင်းကို၄င်း၊ ဆိုက်တခုလုံးကို၄င်း ပိတ်ပင်နိုင်သည်။', # MODIF
	'texte_messages_publics' => 'ဆောင်းပါး၏ လူထုမှာကြားချက်များ',
	'texte_non_fonction_referencement' => 'ဤအလို​အလျောက် ပုံစံကိုသင်​ရွေးချယ်ခွင့်မရှိပါ ထိုဝက်ဘ်ဆိုက်မှ လက်ခံနိုင်သောအရာကို ထည့်သွင်းပါ', # MODIF
	'texte_referencement_automatique' => '<b>အလိုအလျောက် ဝက်ဘ်ဆိုက် အညွှန်းပေးခြင်း</b><br /> ပူးတွဲချိတ်ဆက်မှုလိပ်စာ သို့ ဝက်ဘ်လိပ်စာကို ပေးခြင်းအားဖြင့် ဝက်ဘ်ညွှန်းများကို အမြန်ချိတ်ဆက်နိုင်ပါသည်။ SPIP မှ ဆိုက်၏ ခေါင်းစဉ်၊ ဖော်ပြချက်အကျဉ်း စသည်များကို အလိုအလျောက် ရယူပေးမည်။', # MODIF
	'texte_syndication' => 'ဆိုက်မှခွင့်ပြုထားလျှင် နောက်ဆုံးရ အချက်အလက်များ စာရင်းကို ​အလိုအလျှာက် ထုတ်ပေးနိုင်သည်။ ဤလုပ်ဆောင်မှုကို ရယူရန် ပူးတွဲချိတ်ဆက်ခြင်းကို ခွင့်ပြုထားရန်လိုသည်။ <blockquote><i>တချို့ဆိုက်များတွင် ပိတ်ထားနေသတ်သည်</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'ဤဝက်ဘ်ဆိုက်မှ ဆွဲထုတ်ထားသော ပူးတွဲချိတ်ဆက်ထားသော ဆောင်းပါးများ',
	'titre_dernier_article_syndique' => 'နောက်ဆုံး ပူးတွဲချိတ်ဆက်ထားသော ဆောင်းပါးများ',
	'titre_page_sites_tous' => 'ကိုးကားဝက်ဘ်ဆိုက်များ',
	'titre_referencement_sites' => 'ကိုးကားနေသည့် ပူးတွဲချိတ်ဆက်ထားသော ဝက်ဘ်ဆိုက်များ',
	'titre_site_numero' => 'ဝက်ဘ်ဆိုက်အမှတ်',
	'titre_sites_proposes' => 'ထည့်သွင်းပြီးဝက်ဘ်ဆိုက်များ',
	'titre_sites_references_rubrique' => 'ဤအခန်းကဏ္ဍရှိ ကိုးကားဝက်ဘ်ဆိုက်များ',
	'titre_sites_syndiques' => 'ပူးတွဲချိတ်ဆက်ဝက်ဘ်ဆိုက်များ',
	'titre_sites_tous' => 'ကိုးကားဝက်ဘ်ဆိုက်များ',
	'titre_syndication' => 'ဝက်ဘ်ဆိုက် ပူးတွဲချိတ်ဆက်စေခြင်း'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/sites/lang/sites_my.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=my
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => 'ပူးတွဲချိတ်ဆက်မှု အ​ဆင်မ​​ပြေပါ၊ ချိတ်ဆက်မှုကို မဖတ်နိုင်တာ (သို့) ခွင့်ပြုချက် ပေးမထားခြင်းကြောင့် ဖြစ်နိုင်ပါသည်',
	'avis_echec_syndication_02' => 'ပူးတွဲချိတ်ဆက်မှု အ​ဆင်မ​​ပြေပါ၊ ဤဝက်ဘ်ဆိုက် အတွင်းဘက်နှင့် မချိတ်ဆက်နိုင်ပါ ',
	'avis_site_introuvable' => 'ဝက်ဘ်ဆိုက်ကို မတွေ့ပါ',
	'avis_site_syndique_probleme' => 'သတိပေးချက်၊ ဤဆိုက်၏ ပူးတွဲချိတ်ဆက်မှုတွင် ပြသနာရှိသည်၊ စက်တွင်နောက်ဆက်တွဲ ပြသနာခေတ္တရှိမည်၊ ဆိုက်၏ ပူးတွဲချိတ်ဆက်မှု လိပ်စာကို မှတ်ထားပါ (<b>@url_syndic@</b>) နောက်မှပြန်ကြိုးစားကြည့်ပါ', # MODIF
	'avis_sites_probleme_syndication' => 'ဤဆိုက်များတွင် ပူးတွဲချိတ်ဆက်မှု ပြသနာရှိနေသည်',
	'avis_sites_syndiques_probleme' => 'ဤ​ပူးတွဲချိတ်ဆက်ထား​သည့် ဆိုက်များတွင် ပြသနာရှိသည်',

	// B
	'bouton_radio_modere_posteriori' => 'နောက်မှ ထိန်းသိမ်းခြင်း', # MODIF
	'bouton_radio_modere_priori' => 'ကြိုတင် ထိန်းသိမ်းထားခြင်း', # MODIF
	'bouton_radio_non_syndication' => 'ပူးတွဲချတ်ဆက်မှုမလို',
	'bouton_radio_syndication' => '​ပူးတွဲချတ်ဆက်မှု',

	// E
	'entree_adresse_fichier_syndication' => 'ပူးတွဲချိတ်ဆက်မှုများ၏ လိပ်စာ',
	'entree_adresse_site' => '<b>ဝက်ဘ်ဆိုက်လိပ်စာ</b> [လိုအပ်ပါသည်]',
	'entree_description_site' => 'ဝက်ဘ်ဆိုက်ဖော်ပြချက်',

	// F
	'form_prop_nom_site' => 'ဆိုက်နာမည်',

	// I
	'icone_modifier_site' => 'ဤဝက်ဘ်ဆိုက်ကို ပြန်လည်မွမ်းမံပါ',
	'icone_referencer_nouveau_site' => 'ဝက်ဘ်ဆိုက် အသစ်တခုကို ကိုးကားပါ',
	'icone_voir_sites_references' => 'ကိုးကားဝက်ဘ်ဆိုက်များကို ပြပါ',
	'info_1_site' => '၁ ဝက်ဘ်ဆိုက်',
	'info_a_valider' => '[ထပ်မံအတည်ပြုရန်]',
	'info_bloquer' => 'အကွက်',
	'info_bloquer_lien' => 'ဤဆက်သွယ်မှုကို ပိတ်ပင်ရန်',
	'info_derniere_syndication' => 'ဝက်ဆိုက်၏ နောက်ပူးတွဲချိတ်ဆက်မှုသည် () သို့သွားသည်',
	'info_liens_syndiques_1' => 'အကျိုးတူဆက်နွယ်မှုများ',
	'info_liens_syndiques_2' => 'စံနှုန်းကိုက်ညီမှုစစ်ဆေးချက်ပယ်ဖျက်သည်',
	'info_nom_site_2' => '<b>ဝက်ဘ်ဆိုက်အမည်</b> [လိုအပ်ပါသည်]',
	'info_panne_site_syndique' => 'ပူးတွဲချိတ်ဆက်မှု ပျက်နေသည်',
	'info_probleme_grave' => 'အမှားအယွင်း',
	'info_question_proposer_site' => 'မည်သူက ကိုးကားဝက်ဘ်ဆိုက်များကို ထင်မြင်ချက်ပေးနိုင်သနည်း',
	'info_retablir_lien' => 'ဒီအချိတ်အဆက်ကို ပြန်လည်ထည့်သွင်းရန်',
	'info_site_attente' => 'ဝက်ဘ်ဆိုက် အတည်ပြုချက်ရရန် ဆိုင်းငံ့ခြင်းခံရသည်',
	'info_site_propose' => 'ဝက်ဘ်ဆိုက်ကို တင်သွင်းသည့်နေရာ',
	'info_site_reference' => 'အွန်လိုင်း အညွှန်းဆိုက်များ',
	'info_site_refuse' => 'ဝက်ဘ်ဆိုက်ငြင်းပယ်ခြင်းခံရသည်',
	'info_site_syndique' => 'ဤဝက်ဘ်ဆိုက်သည် ပူးတွဲချိတ်ဆက်ထားသော ဝက်ဘ်ဆိုက်ဖြစ်သည်', # MODIF
	'info_site_valider' => 'အတည်တကျဖြစ်မည့် ဝက်ဘ်ဆိုက်များ',
	'info_sites_referencer' => 'ဆိုက်ညွှန်းခြင်း',
	'info_sites_refuses' => 'ပယ်ဖျက်သည့် ဝက်ဘ်ဆိုက်များ',
	'info_statut_site_1' => 'ဤဝက်ဘ်ဆိုက်သည်',
	'info_statut_site_2' => 'ထုတ်ဝေသည်',
	'info_statut_site_3' => 'တင်ပြထားသည်',
	'info_statut_site_4' => 'အမှိုက်ပုံးထဲတွင်', # MODIF
	'info_syndication' => 'ပူးတွဲချိတ်ဆက်မှု',
	'info_syndication_articles' => 'ဆောင်းပါးများ',
	'item_bloquer_liens_syndiques' => 'ပူးတွဲချိတ်ဆက်မှုများကို အတည်တကျရှိခြင်းမှ ပိတ်ပင်လိုက်ပါ',
	'item_gerer_annuaire_site_web' => 'ဝက်ဘ်ဆိုက်အညွှန်းကို စီမံခန့်ခွဲပါ',
	'item_non_bloquer_liens_syndiques' => 'ပူးတွဲချိတ်ဆက်မှု စတင်နေခြင်းကို ပိတ်ပင်ခြင်း မလုပ်ပါနှင့်',
	'item_non_gerer_annuaire_site_web' => 'ဝက်ဘ်ဆိုက်လမ်းညွှန်ကို အသုံးမပြုနိုင်ပါ',
	'item_non_utiliser_syndication' => 'အလိုအလျေက်ပူးတွဲချိတ်ဆက်မူကို မသုံးပါနှင့်',
	'item_utiliser_syndication' => 'အလိုအလျေက် ပူးတွဲချိတ်ဆက်မှုကို အသုံးပြုပါ',

	// L
	'lien_mise_a_jour_syndication' => 'အခုပြန်လည်မွမ်းမံပါ',
	'lien_nouvelle_recuperation' => 'ဒေတာကို ကာကွယ်မှု ပြန်လည်ပြုလုပ်ရန်ကြိုးစားပါ',

	// S
	'syndic_choix_moderation' => 'ဤဝက်ဘ်ဆိုက်မှ နောက်တစ်ခုသို့ ဆက်နွယ်မှုများတွင် ဘာလုပ်ရမည်လဲ',
	'syndic_choix_oublier' => 'ပူးတွဲချိတ်ဆက်ဖိုင်တွင် အချိန်ကြာမြင့်စွာမရှိတော့သည့် ချိတ်ဆက်မှုကို ဘယ်လိုလုပ်သင့်သလဲ',
	'syndic_choix_resume' => 'အချို့ဝက်ဘ်ဆိုက်များက ဆောင်းပါး၏စာသားအားလုံးကို ကြည့်ခွင့်ပေးသည်။ ပူးတွဲချိတ်ဆက်ရန် ဆန္ဒရှိပါသလား',
	'syndic_lien_obsolete' => 'ဆက်နွယ်မှုအပြည့်စုံ',
	'syndic_option_miroir' => 'အဲဒါတွေကို အလိုအလျောက် ပိတ်ပင်လိုက်ပါ',
	'syndic_option_oubli' => 'အဲဒါတွေကို ဖျက်ပစ်ပါ (ပြီးနောက် @mois@ လများ)',
	'syndic_option_resume_non' => 'ဆောင်းပါးများ၏ အညွှန်းအပြည့်စုံ (HTML ပုံစံ)',
	'syndic_option_resume_oui' => 'နမူနာသာ (စာသားပုံစံ)',
	'syndic_options' => 'ပူးတွဲချိတ်ဆက်မှုဆိုင်ရာ ရွေးချယ်ခွင့်များ',

	// T
	'texte_liens_sites_syndiques' => 'ပြန့်ပွားသော ပူးတွဲချိတ်ဆက်မှု ဆိုက်များကို ပိတ်ပင်ခြင်း ခံရမည်။ ချိတ်ဆက်မှု အချက်အလက်များကို ပူးတွဲချိတ်ဆက်ခြင်း အောင်မြင်စွာ ဖန်တီးပြီးချင်း အောက်တွင်ဖော်ပြပါသည်။ လိပ်စာတခုခြင်းကို၄င်း၊ ဆိုက်တခုလုံးကို၄င်း ပိတ်ပင်နိုင်သည်။', # MODIF
	'texte_messages_publics' => 'ဆောင်းပါး၏ လူထုမှာကြားချက်များ',
	'texte_non_fonction_referencement' => 'ဤအလို​အလျောက် ပုံစံကိုသင်​ရွေးချယ်ခွင့်မရှိပါ ထိုဝက်ဘ်ဆိုက်မှ လက်ခံနိုင်သောအရာကို ထည့်သွင်းပါ', # MODIF
	'texte_referencement_automatique' => '<b>အလိုအလျောက် ဝက်ဘ်ဆိုက် အညွှန်းပေးခြင်း</b><br /> ပူးတွဲချိတ်ဆက်မှုလိပ်စာ သို့ ဝက်ဘ်လိပ်စာကို ပေးခြင်းအားဖြင့် ဝက်ဘ်ညွှန်းများကို အမြန်ချိတ်ဆက်နိုင်ပါသည်။ SPIP မှ ဆိုက်၏ ခေါင်းစဉ်၊ ဖော်ပြချက်အကျဉ်း စသည်များကို အလိုအလျောက် ရယူပေးမည်။', # MODIF
	'texte_syndication' => 'ဆိုက်မှခွင့်ပြုထားလျှင် နောက်ဆုံးရ အချက်အလက်များ စာရင်းကို ​အလိုအလျှာက် ထုတ်ပေးနိုင်သည်။ ဤလုပ်ဆောင်မှုကို ရယူရန် ပူးတွဲချိတ်ဆက်ခြင်းကို ခွင့်ပြုထားရန်လိုသည်။ <blockquote><i>တချို့ဆိုက်များတွင် ပိတ်ထားနေသတ်သည်</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'ဤဝက်ဘ်ဆိုက်မှ ဆွဲထုတ်ထားသော ပူးတွဲချိတ်ဆက်ထားသော ဆောင်းပါးများ',
	'titre_dernier_article_syndique' => 'နောက်ဆုံး ပူးတွဲချိတ်ဆက်ထားသော ဆောင်းပါးများ',
	'titre_page_sites_tous' => 'ကိုးကားဝက်ဘ်ဆိုက်များ',
	'titre_referencement_sites' => 'ကိုးကားနေသည့် ပူးတွဲချိတ်ဆက်ထားသော ဝက်ဘ်ဆိုက်များ',
	'titre_site_numero' => 'ဝက်ဘ်ဆိုက်အမှတ်',
	'titre_sites_proposes' => 'ထည့်သွင်းပြီးဝက်ဘ်ဆိုက်များ',
	'titre_sites_references_rubrique' => 'ဤအခန်းကဏ္ဍရှိ ကိုးကားဝက်ဘ်ဆိုက်များ',
	'titre_sites_syndiques' => 'ပူးတွဲချိတ်ဆက်ဝက်ဘ်ဆိုက်များ',
	'titre_sites_tous' => 'ကိုးကားဝက်ဘ်ဆိုက်များ',
	'titre_syndication' => 'ဝက်ဘ်ဆိုက် ပူးတွဲချိတ်ဆက်စေခြင်း'
);

?>
